# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: engine.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'engine.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65ngine.proto\x12\x06\x65ngine\"\xc0\x01\n\x0cOrderRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04side\x18\x02 \x01(\t\x12\x12\n\norder_type\x18\x03 \x01(\t\x12\x10\n\x08quantity\x18\x04 \x01(\t\x12\x13\n\x0blimit_price\x18\x05 \x01(\t\x12\x12\n\nstop_price\x18\x06 \x01(\t\x12\x15\n\rtime_in_force\x18\x07 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x08 \x01(\t\x12\x17\n\x0f\x63lient_order_id\x18\t \x01(\t\"\xbc\x01\n\rOrderResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x17\n\x0f\x63lient_order_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x12\n\nfilled_qty\x18\x04 \x01(\t\x12\x18\n\x10\x66illed_avg_price\x18\x05 \x01(\t\x12\x17\n\x0fsubmitted_at_ns\x18\x06 \x01(\x03\x12\x1a\n\x12\x61\x63knowledged_at_ns\x18\x07 \x01(\x03\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"!\n\rCancelRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\"0\n\x0e\x43\x61ncelResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x12\n\x10PositionsRequest\"\x81\x01\n\x08Position\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\t\x12\x17\n\x0f\x61vg_entry_price\x18\x03 \x01(\t\x12\x14\n\x0cmarket_value\x18\x04 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x05 \x01(\t\x12\x0c\n\x04side\x18\x06 \x01(\t\"8\n\x11PositionsResponse\x12#\n\tpositions\x18\x01 \x03(\x0b\x32\x10.engine.Position\"\x0f\n\rStatusRequest\"\x87\x02\n\x0eStatusResponse\x12\x13\n\x0b\x65ngine_name\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\x16\n\x0euptime_seconds\x18\x03 \x01(\t\x12\x15\n\rorders_placed\x18\x04 \x01(\x03\x12\x15\n\rorders_filled\x18\x05 \x01(\x03\x12\x1c\n\x14market_data_messages\x18\x06 \x01(\x03\x12\x1c\n\x14\x61vg_tick_to_order_us\x18\x07 \x01(\x01\x12\x1c\n\x14p99_tick_to_order_us\x18\x08 \x01(\x01\x12\x1a\n\x12subscribed_symbols\x18\t \x03(\t\x12\x16\n\x0egateway_status\x18\n \x01(\t\"\x97\x01\n\x11\x43redentialsConfig\x12\x0e\n\x06\x62roker\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x12\n\napi_secret\x18\x03 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x04 \x01(\t\x12\x12\n\naccount_id\x18\x05 \x01(\t\x12\x0f\n\x07user_id\x18\x06 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\"\x10\n\x0e\x41\x63\x63ountRequest\"Y\n\x0f\x41\x63\x63ountResponse\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62uying_power\x18\x02 \x01(\t\x12\x0e\n\x06\x65quity\x18\x03 \x01(\t\x12\x0c\n\x04\x63\x61sh\x18\x04 \x01(\t\"#\n\x0fGetOrderRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\"j\n\x0c\x43onfigUpdate\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\x1d\n\x15max_position_size_usd\x18\x02 \x01(\t\x12\x1c\n\x14max_loss_per_day_usd\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\"0\n\x0e\x43onfigResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"7\n\x10SubscribeRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\x12\n\ndata_types\x18\x02 \x03(\t\"\xa6\x01\n\x10MarketDataUpdate\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\x01\x12\x0c\n\x04size\x18\x04 \x01(\x01\x12\x0b\n\x03\x62id\x18\x05 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x06 \x01(\x01\x12\x10\n\x08\x62id_size\x18\x07 \x01(\x01\x12\x10\n\x08\x61sk_size\x18\x08 \x01(\x01\x12\x14\n\x0ctimestamp_ns\x18\t \x01(\x03\"\x17\n\x15OrderSubscribeRequest\"|\n\x0bOrderUpdate\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x12\n\nfilled_qty\x18\x04 \x01(\t\x12\x11\n\tavg_price\x18\x05 \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x06 \x01(\x03\x32\xa9\x05\n\rEngineService\x12\x39\n\nPlaceOrder\x12\x14.engine.OrderRequest\x1a\x15.engine.OrderResponse\x12<\n\x0b\x43\x61ncelOrder\x12\x15.engine.CancelRequest\x1a\x16.engine.CancelResponse\x12\x43\n\x0cGetPositions\x12\x18.engine.PositionsRequest\x1a\x19.engine.PositionsResponse\x12=\n\nGetAccount\x12\x16.engine.AccountRequest\x1a\x17.engine.AccountResponse\x12:\n\x08GetOrder\x12\x17.engine.GetOrderRequest\x1a\x15.engine.OrderResponse\x12@\n\x0fGetEngineStatus\x12\x15.engine.StatusRequest\x1a\x16.engine.StatusResponse\x12I\n\x14\x43onfigureCredentials\x12\x19.engine.CredentialsConfig\x1a\x16.engine.ConfigResponse\x12<\n\x0cUpdateConfig\x12\x14.engine.ConfigUpdate\x1a\x16.engine.ConfigResponse\x12H\n\x10StreamMarketData\x12\x18.engine.SubscribeRequest\x1a\x18.engine.MarketDataUpdate0\x01\x12J\n\x12StreamOrderUpdates\x12\x1d.engine.OrderSubscribeRequest\x1a\x13.engine.OrderUpdate0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'engine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERREQUEST']._serialized_start=25
  _globals['_ORDERREQUEST']._serialized_end=217
  _globals['_ORDERRESPONSE']._serialized_start=220
  _globals['_ORDERRESPONSE']._serialized_end=408
  _globals['_CANCELREQUEST']._serialized_start=410
  _globals['_CANCELREQUEST']._serialized_end=443
  _globals['_CANCELRESPONSE']._serialized_start=445
  _globals['_CANCELRESPONSE']._serialized_end=493
  _globals['_POSITIONSREQUEST']._serialized_start=495
  _globals['_POSITIONSREQUEST']._serialized_end=513
  _globals['_POSITION']._serialized_start=516
  _globals['_POSITION']._serialized_end=645
  _globals['_POSITIONSRESPONSE']._serialized_start=647
  _globals['_POSITIONSRESPONSE']._serialized_end=703
  _globals['_STATUSREQUEST']._serialized_start=705
  _globals['_STATUSREQUEST']._serialized_end=720
  _globals['_STATUSRESPONSE']._serialized_start=723
  _globals['_STATUSRESPONSE']._serialized_end=986
  _globals['_CREDENTIALSCONFIG']._serialized_start=989
  _globals['_CREDENTIALSCONFIG']._serialized_end=1140
  _globals['_ACCOUNTREQUEST']._serialized_start=1142
  _globals['_ACCOUNTREQUEST']._serialized_end=1158
  _globals['_ACCOUNTRESPONSE']._serialized_start=1160
  _globals['_ACCOUNTRESPONSE']._serialized_end=1249
  _globals['_GETORDERREQUEST']._serialized_start=1251
  _globals['_GETORDERREQUEST']._serialized_end=1286
  _globals['_CONFIGUPDATE']._serialized_start=1288
  _globals['_CONFIGUPDATE']._serialized_end=1394
  _globals['_CONFIGRESPONSE']._serialized_start=1396
  _globals['_CONFIGRESPONSE']._serialized_end=1444
  _globals['_SUBSCRIBEREQUEST']._serialized_start=1446
  _globals['_SUBSCRIBEREQUEST']._serialized_end=1501
  _globals['_MARKETDATAUPDATE']._serialized_start=1504
  _globals['_MARKETDATAUPDATE']._serialized_end=1670
  _globals['_ORDERSUBSCRIBEREQUEST']._serialized_start=1672
  _globals['_ORDERSUBSCRIBEREQUEST']._serialized_end=1695
  _globals['_ORDERUPDATE']._serialized_start=1697
  _globals['_ORDERUPDATE']._serialized_end=1821
  _globals['_ENGINESERVICE']._serialized_start=1824
  _globals['_ENGINESERVICE']._serialized_end=2505
# @@protoc_insertion_point(module_scope)
